function [ fq,fq_err,q] = AzimuthalAverage_Updated190911RPS( FMat, xpix, ypix, pixel_size, num_q )
%AzimuthalAverage Averages an intensity over an isotropic radial surface
%(e.g. circle, ellipse, etc.)
%   Direct application is azimuthal average of a fourier transform image
%   for differential dynamic microscopy. The input arguments will be the
%   image to average (FMat), the number of pixels in x and in y (xpix,
%   ypix), the length of a pixel in um (pixel_size) a vector of length scales over which to average (u = q/2pi), and
%   the number of sampling points per rotation (ntheta). The output
%   argument will be vector of average intensities for various q values.
%   This can then be a row in a total matrix of intensities as a function
%   of time
%

    xsz = xpix-1;
    ysz = ypix-1;
    
    [x_mesh, y_mesh] = meshgrid(-xsz/2:xsz/2,-ysz/2:ysz/2);
    
    q_mesh_x = x_mesh*2*pi/(xpix*pixel_size);
    q_mesh_y = y_mesh*2*pi/(ypix*pixel_size);

    q_mesh = sqrt(q_mesh_x.^2+q_mesh_y.^2);
    
    q_sorted = sort(min(q_mesh));
    
    q_min = q_sorted(3);
    q_max = max(max(q_mesh.*~isinf(q_mesh)));
    
    qbins = logspace(log10(q_min),log10(q_max),num_q+1);
    
    q = (qbins(1:end-1)+qbins(2:end))/2;
    
    %% Update: generated a q range. now find pixels within the range and add up to average and get stdev for error
    
    fq = zeros(1,num_q);
    fq_err = zeros(1,num_q);
    
    for j = 1:num_q-1
        bins = q_mesh>=qbins(j) & q_mesh<qbins(j+1) & abs(x_mesh) > 1 & abs(y_mesh)>1;

           n = sum(sum(bins));
        
        if n ~=0
            fq(j) = sum(FMat(bins))/n;
            fq_err(j) = sqrt(var(FMat(bins)));
        else
            fq(j) = NaN;
            fq_err(j) = NaN;
        end
    end
    
end